==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/Defaults.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
import { DeviceUtils } from "igniteui-react-core";
import { ColorUtil } from "igniteui-react-core";
/**
 * @hidden
 */
export let Defaults = /*@__PURE__*/ (() => {
    class Defaults extends Base {
    }
    Defaults.$t = /*@__PURE__*/ markType(Defaults, 'Defaults');
    Defaults.ae = /*@__PURE__*/ BrushUtil.h(255, 187, 187, 187);
    Defaults.j = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.ag = /*@__PURE__*/ BrushUtil.h(255, 255, 255, 255);
    Defaults.af = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.v = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.w = 8;
    Defaults.u = 8;
    Defaults.t = 0;
    Defaults.s = /*@__PURE__*/ DeviceUtils.g(12);
    Defaults.r = /*@__PURE__*/ DeviceUtils.g(12);
    Defaults.ab = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.ad = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.ac = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.ah = /*@__PURE__*/ BrushUtil.h(255, 238, 88, 121);
    Defaults.ai = /*@__PURE__*/ BrushUtil.h(255, 238, 88, 121);
    Defaults.l = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.k = /*@__PURE__*/ DeviceUtils.g(5);
    Defaults.g = 1;
    Defaults.i = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.h = /*@__PURE__*/ DeviceUtils.g(4);
    Defaults.c = 1;
    Defaults.e = 2;
    Defaults.aq = /*@__PURE__*/ ColorUtil.t("#000000");
    Defaults.ap = /*@__PURE__*/ ColorUtil.t("#ee5879");
    Defaults.al = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.ak = /*@__PURE__*/ BrushUtil.h(255, 238, 88, 121);
    Defaults.q = /*@__PURE__*/ DeviceUtils.g(4);
    Defaults.x = /*@__PURE__*/ DeviceUtils.g(5);
    Defaults.aa = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.am = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.z = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.y = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.f = 1;
    Defaults.b = 1;
    Defaults.aj = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.p = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.o = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.d = 1;
    Defaults.a = 1;
    Defaults.n = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.m = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.ao = /*@__PURE__*/ BrushUtil.h(255, 170, 211, 223);
    Defaults.an = /*@__PURE__*/ BrushUtil.h(255, 255, 255, 255);
    return Defaults;
})();

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/Defaults.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
import { DeviceUtils } from "igniteui-react-core";
import { ColorUtil } from "igniteui-react-core";
/**
 * @hidden
 */
export let Defaults = /*@__PURE__*/ (() => {
    class Defaults extends Base {
    }
    Defaults.$t = /*@__PURE__*/ markType(Defaults, 'Defaults');
    Defaults.ae = /*@__PURE__*/ BrushUtil.h(255, 187, 187, 187);
    Defaults.j = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.ag = /*@__PURE__*/ BrushUtil.h(255, 255, 255, 255);
    Defaults.af = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.v = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.w = 8;
    Defaults.u = 8;
    Defaults.t = 0;
    Defaults.s = /*@__PURE__*/ DeviceUtils.g(12);
    Defaults.r = /*@__PURE__*/ DeviceUtils.g(12);
    Defaults.ab = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.ad = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.ac = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.ah = /*@__PURE__*/ BrushUtil.h(255, 238, 88, 121);
    Defaults.ai = /*@__PURE__*/ BrushUtil.h(255, 238, 88, 121);
    Defaults.l = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.k = /*@__PURE__*/ DeviceUtils.g(5);
    Defaults.g = 1;
    Defaults.i = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.h = /*@__PURE__*/ DeviceUtils.g(4);
    Defaults.c = 1;
    Defaults.e = 2;
    Defaults.aq = /*@__PURE__*/ ColorUtil.u("#000000");
    Defaults.ap = /*@__PURE__*/ ColorUtil.u("#ee5879");
    Defaults.al = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.ak = /*@__PURE__*/ BrushUtil.h(255, 238, 88, 121);
    Defaults.q = /*@__PURE__*/ DeviceUtils.g(4);
    Defaults.x = /*@__PURE__*/ DeviceUtils.g(5);
    Defaults.aa = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.am = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.z = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.y = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.f = 1;
    Defaults.b = 1;
    Defaults.aj = /*@__PURE__*/ BrushUtil.h(255, 0, 0, 0);
    Defaults.p = /*@__PURE__*/ DeviceUtils.g(1);
    Defaults.o = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.d = 1;
    Defaults.a = 1;
    Defaults.n = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.m = /*@__PURE__*/ DeviceUtils.g(2);
    Defaults.ao = /*@__PURE__*/ BrushUtil.h(255, 170, 211, 223);
    Defaults.an = /*@__PURE__*/ BrushUtil.h(255, 255, 255, 255);
    return Defaults;
})();
